@@ -25,12 +25,12 @@
 """This is the "netster.py" module and it provides one function called print_tool()
 while prints lists that may or may not include nested list."""
 
-def print_tool(the_list,indent=False,level=0):
+def print_tool(the_list,indent=False,level=0,fh=sys.stdout):
     for each_item in the_list:
         if isinstance(each_item,list):
-            print_tool(each_item,indent,level+1)
+            print_tool(each_item,indent,level+1,fh)
         else:
             if indent:
                 for tab_stop in range(level):
-                    print("\t", end=' ')
-            print(each_item)
+                    print("\t", end=' ',file=fh)
+            print(each_item,file=fh)
